@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Script::Runner;
-$Bitcoin::Crypto::Script::Runner::VERSION = '4.001';
+$Bitcoin::Crypto::Script::Runner::VERSION = '4.002';
 use v5.10;
 use strict;
 use warnings;
@@ -15,6 +15,7 @@ use Bitcoin::Crypto::Types -types;
 use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Helpers qw(pad_hex);
 use Bitcoin::Crypto::Script::Transaction;
+use Bitcoin::Crypto::Transaction::Flags;
 
 use namespace::clean;
 
@@ -29,10 +30,20 @@ has option 'transaction' => (
 			InstanceOf ['Bitcoin::Crypto::Transaction'],
 			q{Bitcoin::Crypto::Script::Transaction->new(transaction => $_)}
 		),
+	trigger => 1,
 	writer => 1,
 	clearer => 1,
 );
 
+has param 'flags' => (
+	coerce => (InstanceOf ['Bitcoin::Crypto::Transaction::Flags'])
+		->plus_coercions(
+			Undef, q{Bitcoin::Crypto::Transaction::Flags->new}
+		),
+	writer => 1,
+	default => undef,
+);
+
 has field 'stack' => (
 	isa => ArrayRef [Str],
 	writer => -hidden,
@@ -66,6 +77,13 @@ has field '_valid' => (
 	clearer => 1,
 );
 
+sub _trigger_transaction
+{
+	my ($self) = @_;
+
+	$self->transaction->set_runner($self);
+}
+
 sub _stack_error
 {
 	die 'stack error';
@@ -232,6 +250,9 @@ sub start
 	try {
 		Bitcoin::Crypto::Exception::ScriptCompilation->trap_into(
 			sub {
+				die 'cannot run tapscript without taproot flag'
+					if $self->is_tapscript && !$self->flags->taproot;
+
 				$self->compile;
 			}
 		);
@@ -579,6 +600,14 @@ I<predicate:> C<has_transaction>
 
 I<writer:> C<set_transaction>
 
+=head3 flags
+
+An instance of L<Bitcoin::Crypto::Transaction::Flags>. If not passed, full set
+of consensus flags will be assumed (same as calling
+L<Bitcoin::Crypto::Transaction::Flags/new> with no arguments).
+
+I<writer:> C<set_flags>
+
 =head3 script
 
 The current script being executed. Will be set automatically in L</start>.
