@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Transaction::Digest;
-$Bitcoin::Crypto::Transaction::Digest::VERSION = '4.001';
+$Bitcoin::Crypto::Transaction::Digest::VERSION = '4.002';
 use v5.10;
 use strict;
 use warnings;
@@ -16,6 +16,7 @@ use Bitcoin::Crypto::Exception;
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Transaction::Digest::Config;
 use Bitcoin::Crypto::Transaction::Digest::Result;
+use Bitcoin::Crypto::Transaction::Flags;
 
 use namespace::clean;
 
@@ -24,6 +25,12 @@ has param 'transaction' => (
 	weak_ref => 1,
 );
 
+has param 'flags' => (
+	isa => InstanceOf ['Bitcoin::Crypto::Transaction::Flags'],
+	writer => 1,
+	lazy => sub { Bitcoin::Crypto::Transaction::Flags->new },
+);
+
 has field 'config' => (
 	coerce => (InstanceOf ['Bitcoin::Crypto::Transaction::Digest::Config'])
 		->plus_coercions(HashRef, q{Bitcoin::Crypto::Transaction::Digest::Config->new($_)}),
@@ -57,10 +64,10 @@ sub get_digest
 	) if !$input;
 
 	my $procedure = '_get_digest_default';
-	if ($input->is_taproot) {
+	if ($self->flags->taproot && $input->is_taproot) {
 		$procedure = '_get_digest_taproot';
 	}
-	elsif ($input->is_segwit) {
+	elsif ($self->flags->segwit && $input->is_segwit) {
 		$procedure = '_get_digest_segwit';
 	}
 
